import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie } from 'd3';

const height = 500;
const width = 960;
const centerX = width / 2;
const centerY = height / 2;

const csvURL =
  'https://gist.githubusercontent.com/AremTheEnigma/8a7ed1cb3cf35c51771b67c1a3bb509e/raw/CSS%2520Named%2520Colors.csv';

const pieArc = arc()
  .innerRadius(0)
  .outerRadius(width);

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    csv(csvURL).then((data) => {
      setData(data);
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }
  
  const colorPie = pie().value(1);
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${centerX}, ${centerY})`}>
        {colorPie(data)
          .map(d => (
            <path
              fill={d.data['RGB hex value']}
              d={pieArc(d)}
            />
          ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
